Crate workspacer_lossless_file

Structs

LosslessFile
A “lossless” representation of an entire Rust file, preserving all comments/whitespace (via InterstitialSegment) plus each recognized item’s exact original text in LosslessItem.
LosslessItem
An item with its exact text snippet. We do not store a separate range because ConsolidatedItem already has text_range() (e.g. for a CrateInterfaceItem, it is ci.text_range()).

Enums

SegmentKind
Distinguishes an Item vs an Interstitial in the layout.